@@ -569,7 +569,7 @@ def indexacion(df1,mini,maxi):
 
 # Gráfica de boxplots
 def grafico_boxplot_rcParams(df2):
-    plt.rcParams['figure.figsize'] = (9,6);
+    plt.rcParams['figure.figsize'] = (7,5);
     sns.boxplot(data=df2.sort_values(by=['Index_antiguedad_10'],
               ascending=True, inplace=False), 
               x="Index_antiguedad_10", y="valor",
@@ -668,12 +668,12 @@ def RForest(Xtrain,Xtest,ytrain,ytest,k,maxfeat):
 
 def RForestEleccion(df2,k,maxfeat):
     # Entrenamiento
-    Xtodos_train, Xtodos_test, ytodos_train, ytodos_test,Xtodos=Entrenamiento(df2,0.2)
+    Xtodos_train_inicial, Xtodos_test, ytodos_train, ytodos_test,Xtodos=Entrenamiento(df2,0.2)
     # Escala
-    Xtodos_train, Xtodos_test,scl1 =Escalas(Xtodos_train, Xtodos_test)
+    Xtodos_train, Xtodos_test,scl1 =Escalas(Xtodos_train_inicial, Xtodos_test)
     # Random Forest
     rforest1,y_pred43=RForest(Xtodos_train,Xtodos_test,ytodos_train,ytodos_test,k,maxfeat)
-    return scl1,ytodos_test,y_pred43,rforest1,Xtodos_train
+    return scl1,ytodos_test,y_pred43,rforest1,Xtodos_train_inicial
 
 # XGB para un par de datos
 def XGB(Xtrain,Xtest,ytrain,ytest,k):
@@ -691,9 +691,9 @@ def XGB(Xtrain,Xtest,ytrain,ytest,k):
 
 def XGB_Eleccion(df2,k):
     # Entrenamientos
-    Xtodos_train, Xtodos_test, ytodos_train, ytodos_test,Xtodos=Entrenamiento(df2,0.2)
+    Xtodos_train_inicial, Xtodos_test, ytodos_train, ytodos_test,Xtodos=Entrenamiento(df2,0.2)
     # Escalas
-    Xtodos_train, Xtodos_test,scl1 =Escalas(Xtodos_train, Xtodos_test)
+    Xtodos_train, Xtodos_test,scl1 =Escalas(Xtodos_train_inicial, Xtodos_test)
     # XGBs
     xgb1,y_pred43=XGB(Xtodos_train,Xtodos_test,ytodos_train,ytodos_test,k)
 
@@ -702,7 +702,7 @@ def XGB_Eleccion(df2,k):
     #print("El método de Extreme Gradient Boosting se ha ejecutado con éxito. Se procederá a guardar los resultados.")
     #joblib.dump(xgb1,"XGB_"+str(cve)+".joblib")
     # (Se hace aparte)
-    return scl1,ytodos_test,y_pred43,xgb1,Xtodos_train
+    return scl1,ytodos_test,y_pred43,xgb1,Xtodos_train_inicial
 
 # Error para los 4 modelos
 def porcentajeerror2(e,f,g,h):  ##### MODIFICADA POR TENER RL Y ENET #####
@@ -954,7 +954,7 @@ def ModeloFinal(reml2,scls,models,cve,Malerta1,Malerta2): ### MOD X TENER RL Y E
         scaler_file = "escala_Final_"+str(cve)+".save"
         joblib.dump(scls[0], scaler_file)
         joblib.dump(models[0],"Modelo_Final_"+str(cve)+".joblib")
-        Malerta1.to_excel("Muestra_Alertas_"+str(cve))
+        Malerta1.to_excel("Muestra_Alertas_"+str(cve)+".xlsx")
         return models[0],scls[0],Malerta1
     
     elif p==a4: 
@@ -962,6 +962,6 @@ def ModeloFinal(reml2,scls,models,cve,Malerta1,Malerta2): ### MOD X TENER RL Y E
         scaler_file = "escala_Final_"+str(cve)+".save"
         joblib.dump(scls[1], scaler_file)
         joblib.dump(models[1],"Modelo_Final_"+str(cve)+".joblib")
-        Malerta2.to_excel("Muestra_Alertas_"+str(cve))
+        Malerta2.to_excel("Muestra_Alertas_"+str(cve)+".xlsx")
         return models[1],scls[1],Malerta2
 
